..
    This file is part of Invenio.
    Copyright (C) 2015-2019 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Contributors
============

- Alex Ioannidis
- Alexander Ioannidis
- Alizee Pace
- Aman Jain
- Chris Topaloudis
- Francois DECOURCELLE
- Javier Delgado
- Jiri Kuncar
- Lars Holm Nielsen
- Leonardo Rossi
- Michaël Zasso
- Sam Arbid (KTH)
- Sami Hiltunen
- Tibor Simko
